@@ -529,7 +529,8 @@ function data_query_item_edit() {
 				AND sqgr.data_template_id = ?
 				WHERE dtr.data_template_id = ?
 				AND dtr.local_data_id = 0
-				ORDER BY dtr.data_source_name', array(get_request_var('id'), $data_template['id'], $data_template['id']));
+				ORDER BY dtr.data_source_name', 
+				array(get_request_var('id'), $data_template['id'], $data_template['id']));
 
 			$i = 0;
 			if (sizeof($data_template_rrds)) {
@@ -558,7 +559,7 @@ function data_query_item_edit() {
 
 									if (isset($snmp_queries['fields']) && sizeof($snmp_queries['fields'])) {
 										foreach ($snmp_queries['fields'] as $field_name => $field_array) {
-											if ($field_array['direction'] == 'output') {
+											if ($field_array['direction'] == 'output' || $field_array['direction'] == 'input-output') {
 												$xml_outputs[$field_name] = $field_name . ' (' . $field_array['name'] . ')';
 											}
 										}
@@ -1107,7 +1108,7 @@ function data_query() {
 	html_end_box();
 
 	/* form the 'where' clause for our main sql query */
-	if (strlen(get_request_var('filter'))) {
+	if (get_request_var('filter') != '') {
 		$sql_where = "WHERE (sq.name like '%%" . get_request_var('filter') . "%%' OR di.name like '%%" . get_request_var('filter') . "%%')";
 	} else {
 		$sql_where = '';
