@@ -60,6 +60,23 @@ switch (get_request_var('action')) {
 		item_moveup();
 
 		header('Location: graphs.php?header=false&action=graph_edit&id=' . get_request_var('local_graph_id'));
+		break;
+	case 'ajax_graph_items':
+		$sql_where = '';
+
+		load_current_session_value('host_id', 'sess_graph_items_hi', '-1');
+		load_current_session_value('data_template_id', 'sess_graph_items_dti', '-1');
+
+		if (get_filter_request_var('host_id') > 0) {
+			$sql_where .= 'dl.host_id=' . get_request_var('host_id');
+		}
+
+		if (get_filter_request_var('data_template_id') > 0) {
+			$sql_where .= ($sql_where != '' ? ' AND ':'') . 'dtd.data_template_id=' . get_request_var('data_template_id');
+		}
+
+		get_allowed_ajax_graph_items(true, $sql_where);
+
 		break;
 }
 
@@ -272,19 +289,16 @@ function item_edit() {
 	/* ================= input validation ================= */
 	get_filter_request_var('id');
 	get_filter_request_var('host_id');
-	get_filter_request_var('graph_template_id');
 	get_filter_request_var('local_graph_id');
-	get_filter_request_var('host_id');
 	get_filter_request_var('data_template_id');
 	/* ==================================================== */
 
-	/* remember these search fields in session vars so we don't have to keep passing them around */
-	load_current_session_value('local_graph_id', 'sess_local_graph_id', '');
-	load_current_session_value('host_id', 'sess_ds_host_id', '-1');
-	load_current_session_value('data_template_id', 'sess_data_template_id', '-1');
-
 	$id = (!isempty_request_var('id') ? '&id=' . get_request_var('id') : '');
-	$host = db_fetch_row_prepared('SELECT hostname FROM host WHERE id = ?', array(get_request_var('host_id')));
+
+	$host = db_fetch_row_prepared('SELECT hostname 
+		FROM host 
+		WHERE id = ?', 
+		array(get_request_var('host_id')));
 
 	if (empty($host['hostname'])) {
 		$header = __('Data Sources [No Device]');
@@ -300,25 +314,7 @@ function item_edit() {
 		<form name='form_graph_items' action='graphs_items.php'>
 			<table class='filterTable'>
 				<tr>
-					<td>
-						<?php print __('Device');?>
-					</td>
-					<td>
-						<select id='host_id' onChange='applyFilter()'>
-							<option value='-1'<?php if (get_request_var('host_id') == '-1') {?> selected<?php }?>><?php print __('Any');?></option>
-							<option value='0'<?php if (get_request_var('host_id') == '0') {?> selected<?php }?>><?php print __('None');?></option>
-							<?php
-							$hosts = db_fetch_assoc("SELECT id, CONCAT_WS('',description,' (',hostname,')') AS name FROM host ORDER BY description, hostname");
-
-							if (sizeof($hosts) > 0) {
-								foreach ($hosts as $host) {
-									print "<option value='" . $host['id'] . "'" . (get_request_var('host_id') == $host['id'] ? ' selected':'') . '>' . htmlspecialchars($host['name']) . "</option>\n";
-								}
-							}
-							?>
-
-						</select>
-					</td>
+					<?php print html_host_filter(get_request_var('host_id'));?>
 				</tr>
 				<tr>
 					<td class='nowrap'>
@@ -329,7 +325,19 @@ function item_edit() {
 							<option value='-1'<?php if (get_request_var('data_template_id') == '-1') {?> selected<?php }?>><?php print __('Any');?></option>
 							<option value='0'<?php if (get_request_var('data_template_id') == '0') {?> selected<?php }?>><?php print __('None');?></option>
 							<?php
-							$data_templates = db_fetch_assoc('SELECT id, name FROM data_template ORDER BY name');
+							if (get_request_var('host_id') <= 0) {
+								$data_templates = db_fetch_assoc('SELECT id, name 
+									FROM data_template 
+									ORDER BY name');
+							} else {
+								$data_templates = db_fetch_assoc_prepared('SELECT DISTINCT dt.id, dt.name 
+									FROM data_template AS dt
+									INNER JOIN data_local AS dl
+									ON dl.data_template_id=dt.id
+									WHERE dl.host_id = ?
+									ORDER BY name',
+									array(get_request_var('host_id')));
+							}
 
 							if (sizeof($data_templates)) {
 								foreach ($data_templates as $data_template) {
@@ -348,6 +356,9 @@ function item_edit() {
 
 	html_end_box();
 
+	load_current_session_value('host_id', 'sess_graph_items_hi', '-1');
+	load_current_session_value('data_template_id', 'sess_graph_items_dti', '-1');
+
 	if (get_request_var('host_id') > 0) {
 		$sql_where = 'h.id=' . get_request_var('host_id');
 	} elseif (get_request_var('host_id') == 0) {
@@ -365,8 +376,14 @@ function item_edit() {
 	}
 
 	if (!isempty_request_var('id')) {
-		$template_item = db_fetch_row_prepared('SELECT * FROM graph_templates_item WHERE id = ?', array(get_request_var('id')));
-		$host_id       = db_fetch_cell_prepared('SELECT host_id FROM graph_local WHERE id = ?', array(get_request_var('local_graph_id')));
+		$template_item = db_fetch_row_prepared('SELECT * 
+			FROM graph_templates_item 
+			WHERE id = ?', 
+			array(get_request_var('id')));
+	} else {
+		$template_item = array();
+
+		kill_session_var('sess_graph_items_dti');
 	}
 
 	$title = db_fetch_cell_prepared('SELECT title_cache 
@@ -382,15 +399,37 @@ function item_edit() {
 
 	/* by default, select the LAST DS chosen to make everyone's lives easier */
 	if (!isempty_request_var('local_graph_id')) {
-		$default = db_fetch_row_prepared('SELECT task_item_id 
-			FROM graph_templates_item 
-			WHERE local_graph_id = ? 
-			ORDER BY sequence DESC', array(get_request_var('local_graph_id')));
+		$struct_graph_item['task_item_id']['default'] = 0;
 
-		if (sizeof($default) > 0) {
-			$struct_graph_item['task_item_id']['default'] = $default['task_item_id'];
+		if (isset($template_item['task_item_id'])) {
+			$task_item_id = $template_item['task_item_id'];
+			$value = db_fetch_cell_prepared("SELECT
+				CONCAT_WS('', dtd.name_cache,' (', dtr.data_source_name, ')') as name
+				FROM data_local AS dl
+				INNER JOIN data_template_data AS dtd
+				ON dtd.local_data_id=dl.id
+				INNER JOIN data_template_rrd AS dtr
+				ON dtr.local_data_id=dl.id
+				LEFT JOIN host AS h
+				ON dl.host_id=h.id
+				WHERE dtr.id = ?",
+				array($task_item_id));
 		} else {
-			$struct_graph_item['task_item_id']['default'] = 0;
+			$task_item_id = 0;
+			$value = '';
+		}
+
+		if (get_selected_theme() != 'classic') {
+			$struct_graph_item['task_item_id'] = array(
+				'method' => 'drop_callback',
+				'friendly_name' => __('Data Source'),
+				'description' => __('Choose the Data Source to associate with this Graph Item.'),
+				'sql' => '',
+				'action' => 'ajax_graph_items',
+				'none_value' => __('None'),
+				'id' => $task_item_id,
+				'value' => $value
+			);
 		}
 
 		/* modifications to the default graph items array */
@@ -412,6 +451,7 @@ function item_edit() {
 				$struct_graph_item['task_item_id']['sql'] .= " WHERE $sql_where";
 			}
 		}
+
 		$struct_graph_item['task_item_id']['sql'] .= ' ORDER BY name';
 	}
 
@@ -420,8 +460,11 @@ function item_edit() {
 	foreach ($struct_graph_item as $field_name => $field_array) {
 		$form_array += array($field_name => $struct_graph_item[$field_name]);
 
-		$form_array[$field_name]['value'] = (isset($template_item) ? $template_item[$field_name] : '');
-		$form_array[$field_name]['form_id'] = (isset($template_item) ? $template_item['id'] : '0');
+		if ($field_name != 'task_item_id') {
+			$form_array[$field_name]['value']   = (isset($template_item[$field_name]) ? $template_item[$field_name] : '');
+		}
+
+		$form_array[$field_name]['form_id'] = (isset($template_item['id']) ? $template_item['id'] : '0');
 	}
 
 	draw_edit_form(
@@ -432,10 +475,10 @@ function item_edit() {
 	);
 
 	form_hidden_box('local_graph_id', get_request_var('local_graph_id'), '0');
-	form_hidden_box('graph_template_item_id', (isset($template_item) ? $template_item['id'] : '0'), '');
-	form_hidden_box('local_graph_template_item_id', (isset($template_item) ? $template_item['local_graph_template_item_id'] : '0'), '');
-	form_hidden_box('graph_template_id', (isset($template_item) ? $template_item['graph_template_id'] : '0'), '');
-	form_hidden_box('_graph_type_id', (isset($template_item) ? $template_item['graph_type_id'] : '0'), '');
+	form_hidden_box('graph_template_item_id', (!empty($template_item) ? $template_item['id'] : '0'), '');
+	form_hidden_box('local_graph_template_item_id', (!empty($template_item) ? $template_item['local_graph_template_item_id'] : '0'), '');
+	form_hidden_box('graph_template_id', (!empty($template_item) ? $template_item['graph_template_id'] : '0'), '');
+	form_hidden_box('_graph_type_id', (!empty($template_item) ? $template_item['graph_type_id'] : '0'), '');
 	form_hidden_box('save_component_item', '1', '');
 	form_hidden_box('invisible_alpha', $form_array['alpha']['value'], 'FF');
 	form_hidden_box('rrdtool_version', read_config_option('rrdtool_version'), '');
