@@ -709,7 +709,7 @@ function graphs() {
 				if ($xml_array != false) {
 					/* loop through once so we can find out how many input fields there are */
 					foreach ($xml_array['fields'] as $field_name => $field_array) {
-						if ($field_array['direction'] == 'input') {
+						if ($field_array['direction'] == 'input' || $field_array['direction'] == 'input-output') {
 							$num_input_fields++;
 
 							if (!isset($total_rows)) {
@@ -775,7 +775,7 @@ function graphs() {
 
 						if (sizeof($indexes)) {
 							foreach($indexes as $index) {
-								if (strlen($sql_where)) {
+								if ($sql_where != '') {
 									$sql_where .= ", '" . $index['snmp_index'] . "'";
 								} else {
 									$sql_where .= " AND snmp_index IN('" . $index['snmp_index'] . "'";
@@ -786,8 +786,7 @@ function graphs() {
 						}
 					}
 
-					if ((strlen(get_request_var('filter')) == 0) ||
-						((strlen(get_request_var('filter'))) && (sizeof($indexes)))) {
+					if (get_request_var('filter') == '' || (get_request_var('filter') != '' && sizeof($indexes))) {
 						/* determine the sort order */
 						if (isset($xml_array['index_order_type'])) {
 							if ($xml_array['index_order_type'] == 'numeric') {
@@ -863,7 +862,7 @@ function graphs() {
 						html_start_box('', '100%', '', '3', 'center', '');
 
 						foreach ($xml_array['fields'] as $field_name => $field_array) {
-							if ($field_array['direction'] == 'input' && sizeof($field_names)) {
+							if (($field_array['direction'] == 'input' || $field_array['direction'] == 'input-output') && sizeof($field_names)) {
 								foreach($field_names as $row) {
 									if ($row['field_name'] == $field_name) {
 										$html_dq_header .= "<th class='tableSubHeaderColumn'>" . $field_array['name'] . "</th>\n";
@@ -893,7 +892,7 @@ function graphs() {
 
 								$column_counter = 0;
 								foreach ($xml_array['fields'] as $field_name => $field_array) {
-									if ($field_array['direction'] == 'input') {
+									if ($field_array['direction'] == 'input' || $field_array['direction'] == 'input-output') {
 										if (in_array($field_name, $fields)) {
 											if (isset($row[$field_name])) {
 												print "<td><span id='text$query_row" . '_' . $column_counter . "'>" . filter_value($row[$field_name], get_request_var('filter')) . '</span></td>';
@@ -966,7 +965,7 @@ function graphs() {
 		}
 	}
 
-	if (strlen($script)) {
+	if ($script != '') {
 		$script .= "$('.default').click(function() { $.get('graphs_new.php?action=ajax_save&query=" . (isset($snmp_query['id']) ? $snmp_query['id']:'') . "'+'&item='+$(\".dqselect\").val()) });</script>\n";
 		print $script;
 	}
