@@ -80,6 +80,7 @@ $cacti_version_codes = array(
 	'1.1.4'  => '0100',
 	'1.1.5'  => '0100',
 	'1.1.6'  => '0101',
+	'1.1.7'  => '0101',
 );
 
 $messages = array(
@@ -1226,11 +1227,11 @@ $attachment_sizes = array(
 );
 
 $reports_actions = array(
-	REPORTS_SEND_NOW  => 'Send Now',
-	REPORTS_DUPLICATE => 'Duplicate',
-	REPORTS_ENABLE    => 'Enable',
-	REPORTS_DISABLE   => 'Disable',
-	REPORTS_DELETE    => 'Delete',
+	REPORTS_SEND_NOW  => __('Send Now'),
+	REPORTS_DUPLICATE => __('Duplicate'),
+	REPORTS_ENABLE    => __('Enable'),
+	REPORTS_DISABLE   => __('Disable'),
+	REPORTS_DELETE    => __('Delete'),
 );
 
 if (is_realm_allowed(22)) {
@@ -1239,8 +1240,7 @@ if (is_realm_allowed(22)) {
 
 $attach_types = array(
 	REPORTS_TYPE_INLINE_PNG => __('Inline PNG Image'),
-	#REPORTS_TYPE_INLINE_JPG => 'Inline JPEG Image',
-	#REPORTS_TYPE_ATTACH_PDF => 'PDF Attachment',
+	#REPORTS_TYPE_INLINE_JPG => 'Inline JPEG Image'
 );
 
 if (extension_loaded(REPORTS_EXTENSION_GD)) {
