@@ -282,6 +282,7 @@ function draw_edit_control($field_name, &$field_array) {
 			$field_array['action'],
 			$field_array['id'],
 			$field_array['value'],
+			((isset($field_array['none_value'])) ? $field_array['none_value'] : ''),
 			((isset($field_array['default'])) ? $field_array['default'] : ''),
 			((isset($field_array['class'])) ? $field_array['class'] : ''),
 			((isset($field_array['on_change'])) ? $field_array['on_change'] : '')
@@ -509,7 +510,7 @@ function form_filepath_box($form_name, $form_previous_value, $form_default_value
 		$extra_data = "<span class='cactiTooltipHint fa fa-check-circle' style='padding:5px;font-size:16px;color:green' title='" . __('File Found') . "'></span>";
 	}else if (is_dir(trim($form_previous_value))) {
 		$extra_data = "<span class='cactiTooltipHint fa fa-times-circle' style='padding:5px;font-size:16px;color:red' title='" . __('Path is a Directory and not a File') . "'></span>";
-	}else if (strlen($form_previous_value) == 0) {
+	}else if ($form_previous_value == '') {
 		$extra_data = '';
 	} else {
 		$extra_data = "<span class='cactiTooltipHint fa fa-times-circle' style='padding:5px;font-size:16px;color:red' title='" . __('File is Not Found'). "'></span>";
@@ -554,7 +555,7 @@ function form_dirpath_box($form_name, $form_previous_value, $form_default_value,
 		$extra_data = "<span class='cactiTooltipHint fa fa-check-circle' style='padding:5px;font-size:16px;color:green' title='" . __('Directory Found') ."'></span>";
 	}else if (is_file($form_previous_value)) {
 		$extra_data = "<span class='cactiTooltipHint fa fa-times-circle' style='padding:5px;font-size:16px;color:red' title='" . __('Path is a File and not a Directory'). "></span>";
-	}else if (strlen($form_previous_value) == 0) {
+	}else if ($form_previous_value == '') {
 		$extra_data = '';
 	} else {
 		$extra_data = "<span class='cactiTooltipHint fa fa-times-circle' style='padding:5px;font-size:16px;color:red' title='" . __('Directory is Not found'). "'></span>";
@@ -636,7 +637,7 @@ function form_dropdown($form_name, $form_data, $column_display, $column_id, $for
 
 	if (isset($_SESSION['sess_error_fields'])) {
 		if (!empty($_SESSION['sess_error_fields'][$form_name])) {
-			$class .= (strlen($class) ? ' ':'') . 'txtErrorTextBox';
+			$class .= ($class != '' ? ' ':'') . 'txtErrorTextBox';
 			unset($_SESSION['sess_error_fields'][$form_name]);
 		}
 	}
@@ -647,11 +648,11 @@ function form_dropdown($form_name, $form_data, $column_display, $column_id, $for
 		}
 	}
 
-	if (strlen($class)) {
+	if ($class != '') {
 		$class = " class='$class' ";
 	}
 
-	if (strlen($on_change)) {
+	if ($on_change != '') {
 		$on_change = " onChange='$on_change' ";
 	}
 
@@ -673,7 +674,7 @@ function form_callback($form_name, $classic_sql, $column_display, $column_id, $c
 
 	if (isset($_SESSION['sess_error_fields'])) {
 		if (!empty($_SESSION['sess_error_fields'][$form_name])) {
-			$class .= (strlen($class) ? ' ':'') . 'txtErrorTextBox';
+			$class .= ($class != '' ? ' ':'') . 'txtErrorTextBox';
 			unset($_SESSION['sess_error_fields'][$form_name]);
 		}
 	}
@@ -684,11 +685,11 @@ function form_callback($form_name, $classic_sql, $column_display, $column_id, $c
 		}
 	}
 
-	if (strlen($class)) {
+	if ($class != '') {
 		$class = " class='$class' ";
 	}
 
-	if (strlen($on_change)) {
+	if ($on_change != '') {
 		$on_change = " onChange='$on_change' ";
 	}
 
@@ -708,11 +709,16 @@ function form_callback($form_name, $classic_sql, $column_display, $column_id, $c
 	} else {
 		$form_prefix = htmlspecialchars($form_name);
 
-		print "<span id='$form_prefix" . "_wrap' style='width:200px;' class='ui-selectmenu-button ui-widget ui-state-default ui-corner-all'>\n";
-		print "<span id='$form_prefix" . "_click' style='z-index:4' class='ui-icon ui-icon-triangle-1-s'></span>\n";
-		print "<input id='$form_prefix" . "_input' class='ui-selectmenu-text ui-state-default' value='" . htmlspecialchars($previous_value) . "'>\n";
-		print "</span>\n";
-		print "<input type='hidden' id='" . $form_prefix . "' name='" . $form_prefix . "' value='" . $previous_id . "'>\n";
+		print "<span id='$form_prefix" . "_wrap' style='width:300px;' class='autodrop ui-selectmenu-button ui-widget ui-state-default ui-corner-all'>";
+		print "<span id='$form_prefix" . "_click' style='z-index:4' class='ui-icon ui-icon-triangle-1-s'></span>";
+
+		if (!empty($none_entry) && empty($previous_value)) {
+			$previous_value = $none_entry;
+		}
+
+		print "<input id='$form_prefix" . "_input' size='28' class='ui-autocomplete-input ui-state-default ui-selectmenu-text' value='" . htmlspecialchars($previous_value) . "'>";
+		print "<input type='hidden' id='" . $form_prefix . "' name='" . $form_prefix . "' value='" . $previous_id . "'>";
+		print "</span>";
 		?>
 		<script type='text/javascript'>
 		var <?php print $form_name;?>Timer;
@@ -742,7 +748,7 @@ function form_callback($form_name, $classic_sql, $column_display, $column_id, $c
 					<?php print $form_name;?>Open = false;
 				} else {
 					<?php print $form_name;?>ClickTimer = setTimeout(function() {
-						$('#<?php print $form_prefix;?>_input').autocomplete('search', $('#<?php print $form_prefix;?>_input').val());
+						$('#<?php print $form_prefix;?>_input').autocomplete('search', '');
 						clearTimeout(<?php print $form_name;?>Timer);
 						<?php print $form_name;?>Open = true;
 					}, 200);
@@ -798,11 +804,11 @@ function form_checkbox($form_name, $form_previous_value, $form_caption, $form_de
 		}
 	}
 
-	if (strlen($class)) {
+	if ($class != '') {
 		$class = ' ' . trim($class);
 	}
 
-	if (strlen($on_change)) {
+	if ($on_change != '') {
 		$on_change = " onChange='$on_change'";
 	}
 
@@ -833,11 +839,11 @@ function form_radio_button($form_name, $form_previous_value, $form_current_value
 		}
 	}
 
-	if (strlen($class)) {
+	if ($class != '') {
 		$class = " class='$class' ";
 	}
 
-	if (strlen($on_change)) {
+	if ($on_change != '') {
 		$on_change = " onChange='$on_change' ";
 	}
 
@@ -866,7 +872,7 @@ function form_text_area($form_name, $form_previous_value, $form_rows, $form_colu
 
 	if (isset($_SESSION['sess_error_fields'])) {
 		if (!empty($_SESSION['sess_error_fields'][$form_name])) {
-			$class .= (strlen($class) ? ' ':'') . 'txtErrorTextBox';
+			$class .= ($class != '' ? ' ':'') . 'txtErrorTextBox';
 			unset($_SESSION['sess_error_fields'][$form_name]);
 		}
 	}
@@ -877,15 +883,15 @@ function form_text_area($form_name, $form_previous_value, $form_rows, $form_colu
 		}
 	}
 
-	if (strlen($class)) {
+	if ($class != '') {
 		$class = " class='$class' ";
 	}
 
-	if (strlen($on_change)) {
+	if ($on_change != '') {
 		$on_change = " onChange='$on_change' ";
 	}
 
-	if (strlen($placeholder)) {
+	if ($placeholder != '') {
 		$placeholder = " placeholder='$placeholder'";
 	}
 
@@ -920,17 +926,17 @@ function form_multi_dropdown($form_name, $array_display, $sql_previous_values, $
 
 	if (isset($_SESSION['sess_error_fields'])) {
 		if (!empty($_SESSION['sess_error_fields'][$form_name])) {
-			$class .= (strlen($class) ? ' ':'') . 'txtErrorTextBox';
+			$class .= ($class != '' ? ' ':'') . 'txtErrorTextBox';
 			unset($_SESSION['sess_error_fields'][$form_name]);
 		}
 	}
 
 	$class = 'multiselect';
-	if (strlen($class)) {
+	if ($class != '') {
 		$class .= " $class";
 	}
 
-	if (strlen($on_change)) {
+	if ($on_change != '') {
 		$on_change = " onChange='$on_change' ";
 	}
 
@@ -971,7 +977,7 @@ function form_color_dropdown($form_name, $form_previous_value, $form_none_entry,
 		$form_previous_value = $form_default_value;
 	}
 
-	if (strlen($class)) {
+	if ($class != '') {
 		$class = " class='colordropdown $class' ";
 	} else {
 		$class = " class='colordropdown'";
@@ -979,7 +985,7 @@ function form_color_dropdown($form_name, $form_previous_value, $form_none_entry,
 
 	$current_color = db_fetch_cell_prepared('SELECT hex FROM colors WHERE id = ?', array($form_previous_value));
 
-	if (strlen($on_change)) {
+	if ($on_change != '') {
 		$on_change = ' ' . $on_change . ';';
 	}
 
@@ -1047,7 +1053,7 @@ function form_font_box($form_name, $form_previous_value, $form_default_value, $f
 		}
 	}
 
-	if (strlen($form_previous_value) == 0) { # no data: defaults are used; everythings fine
+	if ($form_previous_value == '') { # no data: defaults are used; everythings fine
 			$extra_data = '';
 	} else {
 		/* verifying all possible pango font params is too complex to be tested here
@@ -1112,7 +1118,7 @@ function form_save_button($cancel_url, $force_type = '', $key_field = 'id', $aja
 		} else {
 			$alt = __('Save');
 
-			if (strlen($force_type)) {
+			if ($force_type != '') {
 				$calt   = __('Return');
 			} else {
 				$calt   = __('Cancel');
