@@ -223,87 +223,46 @@ $fields_reports_edit = array(
 );
 
 /* get the hosts sql first */
-if (read_config_option('auth_method') != 0) {
-	/* get policy information for the sql where clause */
-	$current_user = db_fetch_row_prepared('SELECT * 
-		FROM user_auth 
-		WHERE id = ?', 
-		array($_SESSION['sess_user_id']));
-
-	$sql_where    = get_graph_permissions_sql($current_user['policy_graphs'], $current_user['policy_hosts'], $current_user['policy_graph_templates']);
-
-	$hosts_sql = "SELECT DISTINCT host.id, CONCAT_WS('',host.description,' (',host.hostname,')') as name
-		FROM (graph_templates_graph,host)
-		LEFT JOIN graph_local ON (graph_local.host_id=host.id)
-		LEFT JOIN graph_templates ON (graph_templates.id=graph_local.graph_template_id)
-		LEFT JOIN user_auth_perms ON ((graph_templates_graph.local_graph_id=user_auth_perms.item_id and user_auth_perms.type=1 and user_auth_perms.user_id=" . $_SESSION['sess_user_id'] . ') OR (host.id=user_auth_perms.item_id and user_auth_perms.type=3 and user_auth_perms.user_id=' . $_SESSION['sess_user_id'] . ') OR (graph_templates.id=user_auth_perms.item_id and user_auth_perms.type=4 and user_auth_perms.user_id=' . $_SESSION['sess_user_id'] . '))
-		WHERE graph_templates_graph.local_graph_id=graph_local.id
-		AND host_template_id=|arg1:host_template_id|
-		' . (empty($sql_where) ? '' : "AND $sql_where") . '
-		ORDER BY name';
-} else {
-	$hosts_sql = "SELECT DISTINCT host.id, CONCAT_WS('',host.description,' (',host.hostname,')') as name
-		FROM host
-		WHERE host_template_id=|arg1:host_template_id|
-		ORDER BY name";
+$hosts = array();
+if (isset_request_var('host_template_id') && get_filter_request_var('host_template_id') > 0) {
+	$hosts = array_rekey(
+		get_allowed_devices('h.host_template_id =' . get_request_var('host_template_id')),
+		'id', 'description'
+	);
 }
 
-/* next do the templates sql */
-if (read_config_option('auth_method') != 0) {
-	$templates_sql = 'SELECT DISTINCT graph_templates.id, graph_templates.name
-		FROM (graph_templates_graph,graph_local)
-		LEFT JOIN host ON (host.id=graph_local.host_id)
-		LEFT JOIN graph_templates ON (graph_templates.id=graph_local.graph_template_id)
-		LEFT JOIN user_auth_perms ON ((graph_templates_graph.local_graph_id=user_auth_perms.item_id and user_auth_perms.type=1 and user_auth_perms.user_id=' . $_SESSION['sess_user_id'] . ') OR (host.id=user_auth_perms.item_id and user_auth_perms.type=3 and user_auth_perms.user_id=' . $_SESSION['sess_user_id'] . ') OR (graph_templates.id=user_auth_perms.item_id and user_auth_perms.type=4 and user_auth_perms.user_id=' . $_SESSION['sess_user_id'] . '))
-		WHERE graph_templates_graph.local_graph_id=graph_local.id
-		AND graph_templates.id IS NOT NULL
-		AND host_id=|arg1:host_id|
-		' . (empty($sql_where) ? '' : "AND $sql_where") . '
-		ORDER BY name';
-} else {
-	$templates_sql = 'SELECT DISTINCT graph_templates.id, graph_templates.name
-		FROM graph_templates
-		WHERE host_id=|arg1:host_id|
-		ORDER BY name';
+$graph_templates = array();
+if (isset_request_var('host_id') && get_filter_request_var('host_id') > 0) {
+	$graph_templates = array_rekey(
+		get_allowed_graph_templates('h.id = ' . get_request_var('host_id')),
+		'id', 'name'
+	);
 }
 
-/* last do the tree permissions */
-if (read_config_option('auth_method') != 0) {
-	/* all allowed by default */
-	$sql_in = '';
-	if ($current_user['policy_trees'] == 1) {
-		$exclude_trees = db_fetch_assoc_prepared('SELECT item_id
-			FROM user_auth_perms
-			WHERE user_id = ?
-			AND type=2', array($_SESSION['sess_user_id']));
+$sql_where = '';
+$graphs    = array();
+if (isset_request_var('host_template_id') && get_filter_request_var('host_template_id') > 0) {
+	$sql_where = 'h.host_template_id=' . get_request_var('host_template_id');
 
-		if (sizeof($exclude_trees)) {
-			foreach($exclude_trees as $tree) {
-				$sql_in .= (strlen($sql_in) ? ', ':'') . $tree['item_id'];
-			}
+	if (isset_request_var('host_id') && get_filter_request_var('host_id') > 0) {
+		$sql_where .= ($sql_where != '' ? ' AND ':'') . 'gl.host_id=' . get_request_var('host_id');
+
+		if (isset_request_var('graph_template_id') && get_filter_request_var('graph_template_id') > 0) {
+			$sql_where .= ($sql_where != '' ? ' AND ':'') . 'gl.graph_template_id=' . get_request_var('graph_template_id');
+
+			$graphs = array_rekey(
+				get_allowed_graphs($sql_where),
+				'local_graph_id', 'title_cache'
+			);
 		}
-
-		$sql_where = (strlen($sql_in) ? "WHERE id NOT IN ($sql_in)":'');
-	} else {
-		$include_trees = db_fetch_assoc_prepared('SELECT item_id
-			FROM user_auth_perms
-			WHERE user_id = ?
-			AND type=2', array($_SESSION['sess_user_id']));
-
-		if (sizeof($include_trees)) {
-			foreach($include_trees as $tree) {
-				$sql_in .= (strlen($sql_in) ? ', ':'') . $tree['item_id'];
-			}
-		}
-
-		$sql_where = (strlen($sql_in) ? "WHERE id IN ($sql_in)":'');
 	}
-
-	$trees_sql = "SELECT id, name FROM graph_tree $sql_where ORDER BY name";
-} else {
-	$trees_sql = 'SELECT id, name FROM graph_tree ORDER BY name';
 }
 
+$trees = array_rekey(
+	get_allowed_trees(),
+	'id', 'name'
+);
+
 $fields_reports_item_edit = array(
 	'item_type' => array(
 		'friendly_name' => __('Type'),
@@ -312,16 +271,18 @@ $fields_reports_item_edit = array(
 		'description' => __('Item Type to be added.'),
 		'value' => '|arg1:item_type|',
 		'on_change' => 'toggle_item_type()',
-		'array' => $item_types),
+		'array' => $item_types
+	),
 	'tree_id' => array(
 		'friendly_name' => __('Graph Tree'),
-		'method' => 'drop_sql',
+		'method' => 'drop_array',
 		'default' => REPORTS_TREE_NONE,
 		'none_value' => __('None'),
 		'description' => __('Select a Tree to use.'),
 		'value' => '|arg1:tree_id|',
 		'on_change' => 'applyChange(document.reports_item_edit)',
-		'sql' => $trees_sql),
+		'array' => $trees
+	),
 	'branch_id' => array(
 		'friendly_name' => __('Graph Tree Branch'),
 		'method' => 'drop_sql',
@@ -329,24 +290,28 @@ $fields_reports_item_edit = array(
 		'none_value' => __('All'),
 		'description' => __('Select a Tree Branch to use.'),
 		'value' => '|arg1:branch_id|',
-		'sql' => "(SELECT id, CONCAT_WS('', title, ' (Branch)') AS name
+		'sql' => "(SELECT id, CONCAT('" . __('Branch:') . " ', title) AS name
 			FROM graph_tree_items
 			WHERE graph_tree_id=|arg1:tree_id| AND host_id=0 AND local_graph_id=0
+			GROUP BY name
 			ORDER BY position)
 			UNION
-			(SELECT graph_tree_items.id, CONCAT_WS('', description, ' (Device)') AS name
+			(SELECT graph_tree_items.id, CONCAT('" . __('Device:') . " ', description) AS name
 			FROM graph_tree_items
 			INNER JOIN host
 			ON host.id=graph_tree_items.host_id
 			WHERE graph_tree_id=|arg1:tree_id|
+			AND host.id IN(" . implode(',', array_keys(array_rekey(get_allowed_devices(), 'id', 'description'))) . ")
 			GROUP BY name)
-			ORDER BY name"),
+			ORDER BY name"
+	),
 	'tree_cascade' => array(
 		'friendly_name' => __('Cascade to Branches'),
 		'method' => 'checkbox',
 		'default' => '',
 		'description' => __('Should all children branch Graphs be rendered?'),
-		'value' => '|arg1:tree_cascade|' ),
+		'value' => '|arg1:tree_cascade|'
+	),
 	'graph_name_regexp' => array(
 		'friendly_name' => __('Graph Name Regular Expression'),
 		'method' => 'textbox',
@@ -354,7 +319,8 @@ $fields_reports_item_edit = array(
 		'description' => __('A Perl compatible regular expression (REGEXP) used to select graphs to include from the tree.'),
 		'max_length' => 255,
 		'size' => 80,
-		'value' => '|arg1:graph_name_regexp|'),
+		'value' => '|arg1:graph_name_regexp|'
+	),
 	'host_template_id' => array(
 		'friendly_name' => __('Device Template'),
 		'method' => 'drop_sql',
@@ -363,37 +329,38 @@ $fields_reports_item_edit = array(
 		'description' => __('Select a Device Template to use.'),
 		'value' => '|arg1:host_template_id|',
 		'on_change' => 'applyChange(document.reports_item_edit)',
-		'sql' => "SELECT DISTINCT ht.id, ht.name FROM host_template AS ht INNER JOIN host AS h ON h.host_template_id=ht.id ORDER BY name"),
+		'sql' => "SELECT DISTINCT ht.id, ht.name FROM host_template AS ht INNER JOIN host AS h ON h.host_template_id=ht.id ORDER BY name"
+	),
 	'host_id' => array(
 		'friendly_name' => __('Device'),
-		'method' => 'drop_sql',
+		'method' => 'drop_array',
 		'default' => REPORTS_HOST_NONE,
 		'description' => __('Select a Device to specify a Graph'),
 		'value' => '|arg1:host_id|',
 		'none_value' => __('None'),
 		'on_change' => 'applyChange(document.reports_item_edit)',
-		'sql' => $hosts_sql),
+		'array' => $hosts
+	),
 	'graph_template_id' => array(
 		'friendly_name' => __('Graph Template'),
-		'method' => 'drop_sql',
+		'method' => 'drop_array',
 		'default' => '0',
 		'description' => __('Select a Graph Template for the host'),
 		'none_value' => __('None'),
 		'on_change' => 'applyChange(document.reports_item_edit)',
 		'value' => '|arg1:graph_template_id|',
-		'sql' => $templates_sql),
+		'array' => $graph_templates
+	),
 	'local_graph_id' => array(
 		'friendly_name' => __('Graph Name'),
-		'method' => 'drop_sql',
+		'method' => 'drop_array',
 		'default' => '0',
 		'description' => __('The Graph to use for this report item.'),
 		'none_value' => __('None'),
 		'on_change' => 'graphImage(this.value)',
 		'value' => '|arg1:local_graph_id|',
-		'sql' => "SELECT graph_templates_graph.local_graph_id as id, graph_templates_graph.title_cache as name
-			FROM graph_local LEFT JOIN graph_templates_graph ON (graph_local.id=graph_templates_graph.local_graph_id)
-			WHERE graph_local.host_id=|arg1:host_id| AND graph_templates_graph.graph_template_id=|arg1:graph_template_id|
-			ORDER BY name"),
+		'array' => $graphs
+	),
 	'timespan' => array(
 		'friendly_name' => __('Graph Timespan'),
 		'method' => 'drop_array',
@@ -401,33 +368,38 @@ $fields_reports_item_edit = array(
 		'description' => __("Graph End Time is always set to Cacti's schedule.") . '<br>' .
 			__('Graph Start Time equals Graph End Time minus given timespan'),
 		'array' => $graph_timespans,
-		'value' => '|arg1:timespan|'),
+		'value' => '|arg1:timespan|'
+	),
 	'align' => array(
 		'friendly_name' => __('Alignment'),
 		'method' => 'drop_array',
 		'default' => REPORTS_ALIGN_LEFT,
 		'description' => __('Alignment of the Item'),
 		'value' => '|arg1:align|',
-		'array' => $alignment),
+		'array' => $alignment
+	),
 	'item_text' => array(
 		'friendly_name' => __('Fixed Text'),
 		'method' => 'textbox',
 		'default' => '',
 		'description' => __('Enter descriptive Text'),
 		'max_length' => 255,
-		'value' => '|arg1:item_text|'),
+		'value' => '|arg1:item_text|'
+	),
 	'font_size' => array(
 		'friendly_name' => __('Font Size'),
 		'method' => 'drop_array',
 		'default' => REPORTS_FONT_SIZE,
 		'array' => array(7 => 7, 8 => 8, 10 => 10, 12 => 12, 14 => 14, 16 => 16, 18 => 18, 20 => 20, 24 => 24, 28 => 28, 32 => 32),
 		'description' => __('Font Size of the Item'),
-		'value' => '|arg1:font_size|'),
+		'value' => '|arg1:font_size|'
+	),
 	'sequence' => array(
 		'method' => 'view',
 		'friendly_name' => __('Sequence'),
 		'description' => __('Sequence of Item.'),
-		'value' => '|arg1:sequence|'),
+		'value' => '|arg1:sequence|'
+	),
 );
 
 function reports_form_save() {
@@ -489,7 +461,7 @@ function reports_form_save() {
 
 		$save['mailtime']     = form_input_validate($timestamp, 'mailtime', '^[0-9]+$', false, 3);
 
-		if (strlen(get_nfilter_request_var('subject'))) {
+		if (get_nfilter_request_var('subject') != '') {
 			$save['subject'] = get_nfilter_request_var('subject');
 		} else {
 			$save['subject'] = $save['name'];
@@ -508,10 +480,10 @@ function reports_form_save() {
 			($atype != REPORTS_TYPE_ATTACH_GIF) &&
 			($atype != REPORTS_TYPE_INLINE_PNG_LN) &&
 			($atype != REPORTS_TYPE_INLINE_JPG_LN) &&
-			($atype != REPORTS_TYPE_INLINE_GIF_LN) &&
-			($atype != REPORTS_TYPE_ATTACH_PDF)) {
+			($atype != REPORTS_TYPE_INLINE_GIF_LN)) {
 			$atype = REPORTS_TYPE_INLINE_PNG;
 		}
+
 		$save['attachment_type']  = form_input_validate($atype, 'attachment_type', '^[0-9]+$', false, 3);
 		$save['lastsent']         = 0;
 
@@ -525,7 +497,7 @@ function reports_form_save() {
 			}
 		}
 
-		header('Location: ' . get_reports_page() . '?action=edit&id=' . (empty($id) ? get_nfilter_request_var('id') : $id));
+		header('Location: ' . get_reports_page() . '?action=edit&header=false&id=' . (empty($id) ? get_nfilter_request_var('id') : $id));
 		exit;
 	} elseif (isset_request_var('save_component_report_item')) {
 		/* ================= input validation ================= */
@@ -562,9 +534,9 @@ function reports_form_save() {
 			}
 		}
 
-		header('Location: ' . get_reports_page() . '?action=item_edit&id=' . get_nfilter_request_var('report_id') . '&item_id=' . (empty($item_id) ? get_nfilter_request_var('id') : $item_id));
+		header('Location: ' . get_reports_page() . '?action=item_edit&header=false&id=' . get_nfilter_request_var('report_id') . '&item_id=' . (empty($item_id) ? get_nfilter_request_var('id') : $item_id));
 	} else {
-		header('Location: ' . get_reports_page());
+		header('Location: ' . get_reports_page() . '?header=false');
 	}
 	exit;
 }
@@ -618,15 +590,15 @@ function reports_form_actions() {
 
 					reports_send($selected_items[$i]);
 
-					if (isset($_SESSION['reports_message']) && strlen($_SESSION['reports_message'])) {
-						$message .= (strlen($message) ? '<br>':'') . $_SESSION['reports_message'];
+					if (isset($_SESSION['reports_message']) && $_SESSION['reports_message'] != '') {
+						$message .= ($message != '' ? '<br>':'') . $_SESSION['reports_message'];
 					}
-					if (isset($_SESSION['reports_error']) && strlen($_SESSION['reports_error'])) {
-						$message .= (strlen($message) ? '<br>':'') . "<span style='color:red;'>" . $_SESSION['reports_error'] . '</span>';
+					if (isset($_SESSION['reports_error']) && $_SESSION['reports_error'] != '') {
+						$message .= ($message != '' ? '<br>':'') . "<span style='color:red;'>" . $_SESSION['reports_error'] . '</span>';
 					}
 				}
 
-				if (strlen($message)) {
+				if ($message != '') {
 					$_SESSION['reports_message'] = $message;
 					raise_message('reports_message');
 				}
@@ -756,25 +728,25 @@ function reports_send($id) {
 	} elseif ($report['user_id'] == $_SESSION['sess_user_id']) {
 		reports_log(__FUNCTION__ . ', send now, report_id: ' . $id, false, 'REPORTS TRACE', POLLER_VERBOSITY_MEDIUM);
 		/* use report name as default EMail title */
-		if (!strlen($report['subject'])) {
+		if ($report['subject'] == '') {
 			$report['subject'] = $report['name'];
 		};
-		if (!strlen($report['email'])) {
+		if ($report['email'] == '') {
 			$_SESSION['reports_error'] = __('Unable to send Report \'%d\'.  Please set destination e-mail addresses',  $report['name']);
 			if (!isset_request_var('selected_items')) {
 				raise_message('reports_error');
 			}
-		} elseif (!strlen($report['subject'])) {
+		} elseif ($report['subject'] == '') {
 			$_SESSION['reports_error'] = __('Unable to send Report \'%s\'.  Please set an e-mail subject',  $report['name']);
 			if (!isset_request_var('selected_items')) {
 				raise_message('reports_error');
 			}
-		} elseif (!strlen($report['from_name'])) {
+		} elseif ($report['from_name'] == '') {
 			$_SESSION['reports_error'] = __('Unable to send Report \'%s\'.  Please set an e-mail From Name',  $report['name']);
 			if (!isset_request_var('selected_items')) {
 				raise_message('reports_error');
 			}
-		} elseif (!strlen($report['from_email'])) {
+		} elseif ($report['from_email'] == '') {
 			$_SESSION['reports_error'] = __('Unable to send Report \'%s\'.  Please set an e-mail from address',  $report['name']);
 			if (!isset_request_var('selected_items')) {
 				raise_message('reports_error');
@@ -879,7 +851,7 @@ function reports_item_edit() {
 	/* set the default item alignment */
 	$fields_reports_item_edit['font_size']['default'] = $report['font_size'];
 
-	print "<form method='post' action='" . get_current_page() . "' name='reports_item_edit'>\n";
+	form_start(get_current_page(), 'reports_item_edit');
 
 	# ready for displaying the fields
 	html_start_box($header_label, '100%', true, '3', 'center', '');
@@ -1232,10 +1204,20 @@ function display_reports_items($report_id) {
 
 	$css = db_fetch_cell_prepared('SELECT cformat FROM reports WHERE id = ?', array($report_id));
 
-	html_header(array(__('Item'), __('Sequence'), __('Type'), __('Item Details'), __('Timespan'), __('Alignment'), __('Font Size'), __('Actions')), 2);
+	html_header(
+		array(
+			array('display' => __('Item'), 'align' => 'left'),
+			array('display' => __('Sequence'), 'align' => 'left'),
+			array('display' => __('Type'), 'align' => 'left'),
+			array('display' => __('Item Details'), 'align' => 'left'),
+			array('display' => __('Timespan'), 'align' => 'left'),
+			array('display' => __('Alignment'), 'align' => 'left'),
+			array('display' => __('Font Size'), 'align' => 'left'),
+			array('display' => __('Actions'), 'align' => 'right')
+		), 2);
 
-	$i = 0;
-	if (sizeof($items) > 0) {
+	$i = 1;
+	if (sizeof($items)) {
 		foreach ($items as $item) {
 			switch ($item['item_type']) {
 			case REPORTS_ITEM_GRAPH:
@@ -1290,7 +1272,7 @@ function display_reports_items($report_id) {
 			}
 
 			form_alternate_row();
-			$form_data = '<td><a class="linkEditMain" href="' . htmlspecialchars(get_reports_page() . '?action=item_edit&id=' . $report_id. '&item_id=' . $item['id']) . '">Item#' . $i . '</a></td>';$i++;
+			$form_data = '<td><a class="linkEditMain" href="' . htmlspecialchars(get_reports_page() . '?action=item_edit&id=' . $report_id. '&item_id=' . $item['id']) . '">Item#' . $i . '</a></td>';
 			$form_data .= '<td>' . $item['sequence'] . '</td>';
 			$form_data .= '<td>' . $item_types{$item['item_type']} . '</td>';
 			$form_data .= '<td class="nowrap">' . $item_details . '</td>';
@@ -1298,13 +1280,21 @@ function display_reports_items($report_id) {
 			$form_data .= '<td>' . $align . '</td>';
 			$form_data .= '<td>' . $size . '</td>';
 
-			$form_data .= '<td align="right" style="text-align:right;min-width:5%;white-space:nowrap;"><a href="' . htmlspecialchars(get_reports_page() . '?action=item_movedown&item_id=' . $item['id'] . '&id=' . $report_id) . '"><img src="images/move_down.gif" alt="" title="' . __('Move Down') . '"></a>' . '<a	href="' . htmlspecialchars(get_reports_page() . '?action=item_moveup&item_id=' . $item['id'] .	'&id=' . $report_id) . '"><img src="images/move_up.gif" alt="" title="' . __('Move Up') . '"></a>' . '</td>';
+			if ($i == 1) {
+				$form_data .= '<td class="right nowrap"><a class="remover fa fa-caret-down moveArrow" title="' . __('Move Down') . '" href="' . htmlspecialchars(get_reports_page() . '?action=item_movedown&item_id=' . $item['id'] . '&id=' . $report_id) . '"></a>' . '<span class="moveArrowNone"</span></td>';
+			} elseif ($i > 1 && $i < sizeof($items)) {
+				$form_data .= '<td class="right nowrap"><a class="remover fa fa-caret-down moveArrow" title="' . __('Move Down') . '" href="' . htmlspecialchars(get_reports_page() . '?action=item_movedown&item_id=' . $item['id'] . '&id=' . $report_id) . '"></a>' . '<a class="remover fa fa-caret-up moveArrow" title="' . __('Move Up') . '" href="' . htmlspecialchars(get_reports_page() . '?action=item_moveup&item_id=' . $item['id'] .	'&id=' . $report_id) . '"></a>' . '</td>';
+			} else {
+				$form_data .= '<td class="right nowrap"><span class="moveArrowNone"></span>' . '<a class="remover fa fa-caret-up moveArrow" title="' . __('Move Up') . '" href="' . htmlspecialchars(get_reports_page() . '?action=item_moveup&item_id=' . $item['id'] .	'&id=' . $report_id) . '"></a>' . '</td>';
+			}
 
-			$form_data .= '<td align="right"><a class="pid deleteMarker fa fa-remove" href="' . htmlspecialchars(get_reports_page() . '?action=item_remove&item_id=' . $item['id'] . '&id=' . $report_id) . '" title="' . __('Delete') . '"></a>' . '</td></tr>';
+			$form_data .= '<td align="right"><a class="pic deleteMarker fa fa-remove" href="' . htmlspecialchars(get_reports_page() . '?action=item_remove&item_id=' . $item['id'] . '&id=' . $report_id) . '" title="' . __('Delete') . '"></a>' . '</td></tr>';
 			print $form_data;
+
+			$i++;
 		}
 	} else {
-		print "<tr><td><em>" . __('No Report Items') . "</em></td></tr>\n";
+		print '<tr><td colspan="9"><em>' . __('No Report Items') . '</em></td></tr>';
 	}
 }
 
@@ -1431,7 +1421,7 @@ function reports() {
 	form_end();
 
 	/* form the 'where' clause for our main sql query */
-	if (strlen(get_request_var('filter'))) {
+	if (get_request_var('filter') != '') {
 		$sql_where = "WHERE (reports.name LIKE '%%" . get_request_var('filter') . "%%')";
 	} else {
 		$sql_where = '';
@@ -1440,16 +1430,16 @@ function reports() {
 	if (get_request_var('status') == '-1') {
 		/* Show all items */
 	} elseif (get_request_var('status') == '-2') {
-		$sql_where .= (strlen($sql_where) ? " AND reports.enabled='on'" : " WHERE reports.enabled='on'");
+		$sql_where .= ($sql_where != '' ? " AND reports.enabled='on'" : " WHERE reports.enabled='on'");
 	} elseif (get_request_var('status') == '-3') {
-		$sql_where .= (strlen($sql_where) ? " AND reports.enabled=''" : " WHERE reports.enabled=''");
+		$sql_where .= ($sql_where != '' ? " AND reports.enabled=''" : " WHERE reports.enabled=''");
 	}
 
 	/* account for permissions */
 	if (is_reports_admin()) {
 		$sql_join = 'LEFT JOIN user_auth ON user_auth.id=reports.user_id';
 	} else {
-		$sql_where .= (strlen($sql_where) ? ' AND ':'WHERE ') . ' user_auth.id=' . $_SESSION['sess_user_id'];
+		$sql_where .= ($sql_where != '' ? ' AND ':'WHERE ') . ' user_auth.id=' . $_SESSION['sess_user_id'];
 		$sql_join = 'INNER JOIN user_auth ON user_auth.id=reports.user_id';
 	}
 
@@ -1511,10 +1501,23 @@ function reports() {
 		$date_format = reports_date_time_format();
 
 		foreach ($reports_list as $report) {
+			if (!reports_html_account_exists($report['user_id'])) {
+				reports_html_report_disable($report['id']);
+				$report['enabled'] = '';
+			}
+
 			form_alternate_row('line' . $report['id'], true);
+
 			form_selectable_cell(filter_value($report['name'], get_request_var('filter'), get_reports_page() . '?action=edit&tab=details&id=' . $report['id'] . '&page=1'), $report['id']);
 
-			if (is_reports_admin()) form_selectable_cell($report['full_name'], $report['id']);
+			if (is_reports_admin()) { 
+				if (reports_html_account_exists($report['user_id'])) {
+					form_selectable_cell($report['full_name'], $report['id']);
+				} else {
+					form_selectable_cell(__('Report Disabled - No Owner'), $report['id']);
+				}
+			} 
+
 			$interval = 'Every ' . $report['count'] . ' ' . $reports_interval[$report['intrvl']];
 
 			form_selectable_cell($interval, $report['id']);
@@ -1575,3 +1578,10 @@ function reports() {
 	<?php
 }
 
+function reports_html_account_exists($user_id) {
+	return db_fetch_cell_prepared('SELECT id FROM user_auth WHERE id = ?', array($user_id));
+}
+
+function reports_html_report_disable($report_id) {
+	db_execute_prepared('UPDATE reports SET enabled="" WHERE id = ?', array($report_id));
+}
