@@ -147,7 +147,7 @@ function update_poller_cache($data_source, $commit = false) {
 			$field = data_query_field_list($data_input['data_template_data_id']);
 
 			$params = array();
-			if (strlen($field['output_type'])) {
+			if ($field['output_type'] != '') {
 				$output_type_sql = ' AND snmp_query_graph_rrd.snmp_query_graph_id = ?';
 				$params[] = $field['output_type'];
 			} else {
@@ -184,7 +184,7 @@ function update_poller_cache($data_source, $commit = false) {
 				$num_output_fields = sizeof(db_fetch_assoc_prepared('SELECT ' . SQL_NO_CACHE . ' id 
 					FROM data_input_fields 
 					WHERE data_input_id = ? 
-					AND input_output="out" 
+					AND input_output = "out"
 					AND update_rra="on"', 
 					array($data_input['id'])));
 
@@ -469,7 +469,7 @@ function poller_update_poller_cache_from_buffer($local_data_ids, &$poller_items)
 	if (sizeof($poller_items)) {
 		foreach($poller_items as $record) {
 			/* take care of invalid entries */
-			if (strlen($record) == 0) {
+			if ($record == '') {
 				continue;
 			}
 
@@ -568,7 +568,7 @@ function push_out_host($host_id, $local_data_id = 0, $data_template_id = 0) {
 					WHERE dif.data_input_id = ?
 					AND did.data_template_data_id = ?
 					AND (did.t_value="" OR did.t_value is null)
-					AND dif.input_output="in"',
+					AND dif.input_output = "in"',
 					array($data_source['data_input_id'], $data_source['local_data_template_data_id']));
 			}
 
